@@ -3,9 +3,9 @@ from datetime import timedelta as td
 from os import getenv
 
 # libs
-from peewee import AutoField, TextField, ForeignKeyField, TimestampField
+from peewee import AutoField, TextField, ForeignKeyField, TimestampField, IntegerField, BooleanField
+from playhouse.postgres_ext import BinaryJSONField
 from peewee import Model, PostgresqlDatabase
-from playhouse.postgres_ext import IntegerField
 import psycopg2 as pg2
 import psycopg2.extras as pg2_extras
 
@@ -54,6 +54,7 @@ class DataSource(Model):
 	id = AutoField(primary_key=True, null=False)
 	name = TextField(unique=True, null=False)
 	icon_name = TextField(null=False)
+	is_categorical = BooleanField(null=False)
 
 	class Meta:
 		database = db
@@ -107,7 +108,7 @@ class HourlyStats(Model):
 	participant = ForeignKeyField(Participant, on_delete='CASCADE', null=False)
 	data_source = ForeignKeyField(DataSource, on_delete='CASCADE', null=False)
 	ts = TimestampField(null=False)
-	amount = IntegerField(default=0)
+	amount = BinaryJSONField(null=False, default={})
 
 	class Meta:
 		database = db
